package org.jk.system.mapper;



import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import org.jk.system.domain.DocumentAuditInfo;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author takai
 * @date 2025-05-29
 */
public interface DocumentAuditInfoMapper
{
    /**
     * 查询【请填写功能名称】
     *
     * @param documentId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public DocumentAuditInfo selectDocumentAuditInfoByDocumentId(String documentId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param documentAuditInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<DocumentAuditInfo> selectDocumentAuditInfoList(DocumentAuditInfo documentAuditInfo);

    /**
     * 新增【请填写功能名称】
     *
     * @param documentAuditInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertDocumentAuditInfo(DocumentAuditInfo documentAuditInfo);

    /**
     * 修改【请填写功能名称】
     *
     * @param documentAuditInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateDocumentAuditInfo(DocumentAuditInfo documentAuditInfo);

    /**
     * 删除【请填写功能名称】
     *
     * @param documentId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteDocumentAuditInfoByDocumentId(String documentId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param documentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDocumentAuditInfoByDocumentIds(String[] documentIds);

    public Page<DocumentAuditInfo> selectPageList(@Param("ew") DocumentAuditInfo documentAuditInfo,@Param("page") Page page);
}
